==> redkite-0.8.1-2-x86_64.pkg.tar.zst: usr/include/redkite/RkProgressBar.h <==
/**
 * File name: RkProgressBar.h
 * Project: Redkite (A small GUI toolkit)
 *
 * Copyright (C) 2019 Iurie Nistor <http://geontime.com>
 *
 * This file is part of Redkite.
 *
 * Redkite is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef RK_PROGRESS_BAR_H
#define RK_PROGRESS_BAR_H

#include "RkWidget.h"

class RK_EXPORT RkProgressBar : public RkWidget {
 public:
    RkProgressBar(RkWidget *parent);
    int beginValue() const;
    void setBeginValue(int value);
    int endValue() const;
    void setEndValue(int value);
    void setRange(int begin, int end);
    int value() const;
    Rk::Orientation orientation() const;
    void setOrientation(Rk::Orientation orientation);
    void setValue(int value);
    void reset();
    void setProgressColor(const RkColor &color);

 protected:
    virtual void paintEvent(const std::shared_ptr<RkPaintEvent> &event) override;
    RK_DELCATE_IMPL_PTR(RkProgressBar)
};

#endif // RK_PROGRESS_BAR_H

==> redkite-1.0.3-1-x86_64.pkg.tar.zst: usr/include/redkite/RkProgressBar.h <==
/**
 * File name: RkProgressBar.h
 * Project: Redkite (A small GUI toolkit)
 *
 * Copyright (C) 2019 Iurie Nistor <http://geontime.com>
 *
 * This file is part of Redkite.
 *
 * Redkite is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef RK_PROGRESS_BAR_H
#define RK_PROGRESS_BAR_H

#include "RkWidget.h"

class RK_EXPORT RkProgressBar : public RkWidget {
 public:
    explicit RkProgressBar(RkWidget *parent);
    int beginValue() const;
    void setBeginValue(int value);
    int endValue() const;
    void setEndValue(int value);
    void setRange(int begin, int end);
    int value() const;
    Rk::Orientation orientation() const;
    void setOrientation(Rk::Orientation orientation);
    void setValue(int value);
    void reset();
    void setProgressColor(const RkColor &color);

 protected:
    virtual void paintEvent(RkPaintEvent* event) override;

 private:
    RK_DISABLE_COPY(RkProgressBar);
    RK_DISABLE_MOVE(RkProgressBar);
    RK_DELCATE_IMPL_PTR(RkProgressBar);
};

#endif // RK_PROGRESS_BAR_H
